@@ -16,6 +16,7 @@ This module (and all function/classes within this module) should be
 considered internal, and *not* a public API.
 
 """
+
 import copy
 import logging
 import socket
@@ -60,9 +61,18 @@ VALID_ACCOUNT_ID_ENDPOINT_MODE_CONFIG = (
     'required',
 )
 
-class ClientArgsCreator(object):
-    def __init__(self, event_emitter, user_agent, response_parser_factory,
-                 loader, exceptions_factory, config_store, user_agent_creator=None):
+
+class ClientArgsCreator:
+    def __init__(
+        self,
+        event_emitter,
+        user_agent,
+        response_parser_factory,
+        loader,
+        exceptions_factory,
+        config_store,
+        user_agent_creator=None,
+    ):
         self._event_emitter = event_emitter
         self._response_parser_factory = response_parser_factory
         self._loader = loader
@@ -74,25 +84,31 @@ class ClientArgsCreator(object):
             self._session_ua_creator = user_agent_creator
 
     def get_client_args(
-            self,
-            service_model,
-            region_name,
-            is_secure,
-            endpoint_url,
-            verify,
-            credentials,
-            scoped_config,
-            client_config,
-            endpoint_bridge,
-            auth_token=None,
-            endpoints_ruleset_data=None,
-            partition_data=None,
+        self,
+        service_model,
+        region_name,
+        is_secure,
+        endpoint_url,
+        verify,
+        credentials,
+        scoped_config,
+        client_config,
+        endpoint_bridge,
+        auth_token=None,
+        endpoints_ruleset_data=None,
+        partition_data=None,
     ):
         final_args = self.compute_client_args(
-            service_model, client_config, endpoint_bridge, region_name,
-            endpoint_url, is_secure, scoped_config)
+            service_model,
+            client_config,
+            endpoint_bridge,
+            region_name,
+            endpoint_url,
+            is_secure,
+            scoped_config,
+        )
 
-        service_name = final_args['service_name']
+        service_name = final_args['service_name']  # noqa
         parameter_validation = final_args['parameter_validation']
         endpoint_config = final_args['endpoint_config']
         protocol = final_args['protocol']
@@ -107,10 +123,13 @@ class ClientArgsCreator(object):
 
         event_emitter = copy.copy(self._event_emitter)
         signer = RequestSigner(
-            service_model.service_id, signing_region,
+            service_model.service_id,
+            signing_region,
             endpoint_config['signing_name'],
             endpoint_config['signature_version'],
-            credentials, event_emitter, auth_token
+            credentials,
+            event_emitter,
+            auth_token,
         )
 
         config_kwargs['s3'] = s3_config
@@ -118,18 +137,22 @@ class ClientArgsCreator(object):
         endpoint_creator = EndpointCreator(event_emitter)
 
         endpoint = endpoint_creator.create_endpoint(
-            service_model, region_name=endpoint_region_name,
-            endpoint_url=endpoint_config['endpoint_url'], verify=verify,
+            service_model,
+            region_name=endpoint_region_name,
+            endpoint_url=endpoint_config['endpoint_url'],
+            verify=verify,
             response_parser_factory=self._response_parser_factory,
             max_pool_connections=new_config.max_pool_connections,
             proxies=new_config.proxies,
             timeout=(new_config.connect_timeout, new_config.read_timeout),
             socket_options=socket_options,
             client_cert=new_config.client_cert,
-            proxies_config=new_config.proxies_config)
+            proxies_config=new_config.proxies_config,
+        )
 
         serializer = botocore.serialize.create_serializer(
-            protocol, parameter_validation)
+            protocol, parameter_validation
+        )
         response_parser = botocore.parsers.create_parser(protocol)
 
         ruleset_resolver = self._build_endpoint_resolver(
@@ -170,9 +193,16 @@ class ClientArgsCreator(object):
             'user_agent_creator': client_ua_creator,
         }
 
-    def compute_client_args(self, service_model, client_config,
-                            endpoint_bridge, region_name, endpoint_url,
-                            is_secure, scoped_config):
+    def compute_client_args(
+        self,
+        service_model,
+        client_config,
+        endpoint_bridge,
+        region_name,
+        endpoint_url,
+        is_secure,
+        scoped_config,
+    ):
         service_name = service_model.endpoint_prefix
         protocol = self._resolve_protocol(service_model)
         parameter_validation = True
@@ -218,7 +248,8 @@ class ClientArgsCreator(object):
         config_kwargs = dict(
             region_name=endpoint_config['region_name'],
             signature_version=endpoint_config['signature_version'],
-            user_agent=preliminary_ua_string)
+            user_agent=preliminary_ua_string,
+        )
         if 'dualstack' in endpoint_variant_tags:
             config_kwargs.update(use_dualstack_endpoint=True)
         if 'fips' in endpoint_variant_tags:
@@ -276,7 +307,7 @@ class ClientArgsCreator(object):
             'protocol': protocol,
             'config_kwargs': config_kwargs,
             's3_config': s3_config,
-            'socket_options': self._compute_socket_options(scoped_config)
+            'socket_options': self._compute_socket_options(scoped_config),
         }
 
     def _compute_inject_host_prefix(self, client_config, config_kwargs):
@@ -348,8 +379,15 @@ class ClientArgsCreator(object):
         """
         return service_name in ['s3', 's3-control']
 
-    def _compute_endpoint_config(self, service_name, region_name, endpoint_url,
-                                 is_secure, endpoint_bridge, s3_config):
+    def _compute_endpoint_config(
+        self,
+        service_name,
+        region_name,
+        endpoint_url,
+        is_secure,
+        endpoint_bridge,
+        s3_config,
+    ):
         resolve_endpoint_kwargs = {
             'service_name': service_name,
             'region_name': region_name,
@@ -359,31 +397,44 @@ class ClientArgsCreator(object):
         }
         if service_name == 's3':
             return self._compute_s3_endpoint_config(
-                s3_config=s3_config, **resolve_endpoint_kwargs)
+                s3_config=s3_config, **resolve_endpoint_kwargs
+            )
         return self._resolve_endpoint(**resolve_endpoint_kwargs)
 
-    def _compute_s3_endpoint_config(self, s3_config,
-                                    **resolve_endpoint_kwargs):
+    def _compute_s3_endpoint_config(
+        self, s3_config, **resolve_endpoint_kwargs
+    ):
         endpoint_config = self._resolve_endpoint(**resolve_endpoint_kwargs)
         self._set_region_if_custom_s3_endpoint(
-            endpoint_config, resolve_endpoint_kwargs['endpoint_bridge'])
+            endpoint_config, resolve_endpoint_kwargs['endpoint_bridge']
+        )
         return endpoint_config
 
-    def _set_region_if_custom_s3_endpoint(self, endpoint_config,
-                                          endpoint_bridge):
+    def _set_region_if_custom_s3_endpoint(
+        self, endpoint_config, endpoint_bridge
+    ):
         # If a user is providing a custom URL, the endpoint resolver will
         # refuse to infer a signing region. If we want to default to s3v4,
         # we have to account for this.
-        if endpoint_config['signing_region'] is None \
-                and endpoint_config['region_name'] is None:
+        if (
+            endpoint_config['signing_region'] is None
+            and endpoint_config['region_name'] is None
+        ):
             endpoint = endpoint_bridge.resolve('s3')
             endpoint_config['signing_region'] = endpoint['signing_region']
             endpoint_config['region_name'] = endpoint['region_name']
 
-    def _resolve_endpoint(self, service_name, region_name,
-                          endpoint_url, is_secure, endpoint_bridge):
+    def _resolve_endpoint(
+        self,
+        service_name,
+        region_name,
+        endpoint_url,
+        is_secure,
+        endpoint_bridge,
+    ):
         return endpoint_bridge.resolve(
-            service_name, region_name, endpoint_url, is_secure)
+            service_name, region_name, endpoint_url, is_secure
+        )
 
     def _compute_socket_options(self, scoped_config):
         # This disables Nagle's algorithm and is the default socket options
@@ -393,7 +444,8 @@ class ClientArgsCreator(object):
             # Enables TCP Keepalive if specified in shared config file.
             if self._ensure_boolean(scoped_config.get('tcp_keepalive', False)):
                 socket_options.append(
-                    (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1))
+                    (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
+                )
         return socket_options
 
     def _compute_retry_config(self, config_kwargs):
@@ -736,4 +788,4 @@ class ClientArgsCreator(object):
                 f"invalid. Valid values are: {VALID_ACCOUNT_ID_ENDPOINT_MODE_CONFIG}."
             )
 
-        config_kwargs[config_key] = account_id_endpoint_mode
\ No newline at end of file
+        config_kwargs[config_key] = account_id_endpoint_mode
