@@ -1,14 +1,14 @@
 import json
 import math
-import sys
-import time
-import psutil
-
 import os
 import shutil
-from awscli.botocore.awsrequest import AWSResponse
-
+import sys
+import time
 from unittest import mock
+
+import psutil
+
+from awscli.botocore.awsrequest import AWSResponse
 from awscli.clidriver import AWSCLIEntryPoint, create_clidriver
 from awscli.compat import BytesIO
 
@@ -105,7 +105,7 @@ class RawResponse(BytesIO):
             contents = self.read()
 
 
-class StubbedHTTPClient(object):
+class StubbedHTTPClient:
     """
     A generic stubbed HTTP client.
     """
@@ -136,7 +136,7 @@ class StubbedHTTPClient(object):
         self._responses.append(response)
 
 
-class ProcessBenchmarker(object):
+class ProcessBenchmarker:
     """
     Periodically samples CPU and memory usage of a process given its pid.
     """
@@ -192,7 +192,7 @@ class ProcessBenchmarker(object):
         return samples
 
 
-class BenchmarkHarness(object):
+class BenchmarkHarness:
     _DEFAULT_FILE_CONFIG_CONTENTS = "[default]"
 
     """
@@ -270,16 +270,23 @@ class BenchmarkHarness(object):
         # setup and stub HTTP client
         client.setup()
         self._stub_responses(
-            benchmark.get('responses', [{"headers": {}, "body": ""}]), client
+            benchmark.get('responses', [{"headers": {}, "body": ""}]),
+            client,
+            result_dir,
         )
 
-    def _stub_responses(self, responses, client):
+    def _stub_responses(self, responses, client, result_dir):
         """
         Stubs the supplied HTTP client using the response instructions in the supplied
         responses struct. Each instruction will generate one or more stubbed responses.
         """
         for response in responses:
             body = response.get("body", "")
+            # if body is a dict, load the contents from a file
+            if isinstance(body, dict):
+                contents_path = os.path.join(result_dir, body['file'])
+                with open(contents_path) as contents_f:
+                    body = contents_f.read()
             headers = response.get("headers", {})
             status_code = response.get("status_code", 200)
             # use the instances key to support duplicating responses a configured number of times
@@ -326,7 +333,13 @@ class BenchmarkHarness(object):
         metrics_f.close()
 
     def _run_isolated_benchmark(
-        self, result_dir, benchmark, client, process_benchmarker, args
+        self,
+        result_dir,
+        benchmark,
+        client,
+        process_benchmarker,
+        iteration,
+        args,
     ):
         """
         Runs a single iteration of one benchmark execution. Includes setting up
@@ -355,9 +368,31 @@ class BenchmarkHarness(object):
                 with open(child_output_path, 'w') as out, open(
                     child_err_path, 'w'
                 ) as err:
-                    # redirect standard output of the child process to a file
-                    os.dup2(out.fileno(), sys.stdout.fileno())
-                    os.dup2(err.fileno(), sys.stderr.fileno())
+                    if not args.debug_dir:
+                        # redirect standard output of the child process to a file
+                        os.dup2(out.fileno(), sys.stdout.fileno())
+                        os.dup2(err.fileno(), sys.stderr.fileno())
+                    else:
+                        with open(
+                            os.path.abspath(
+                                os.path.join(
+                                    args.debug_dir,
+                                    f'{benchmark["name"]}-{iteration}.txt',
+                                )
+                            ),
+                            'w',
+                        ) as f:
+                            with open(
+                                os.path.abspath(
+                                    os.path.join(
+                                        args.debug_dir,
+                                        f'{benchmark["name"]}-{iteration}-err.txt',
+                                    )
+                                ),
+                                'w',
+                            ) as f_err:
+                                os.dup2(f.fileno(), sys.stdout.fileno())
+                                os.dup2(f_err.fileno(), sys.stderr.fileno())
                     # execute command on child process
                     self._run_command_with_metric_hooks(
                         benchmark['command'], metrics_path
@@ -373,10 +408,10 @@ class BenchmarkHarness(object):
                 raise RuntimeError(
                     'Child process execution failed: output file not found.'
                 )
-            metrics_f = json.load(open(metrics_path, 'r'))
+            metrics_f = json.load(open(metrics_path))
             # raise error if child process failed
             if (rc := metrics_f['return_code']) != 0:
-                with open(child_err_path, 'r') as err:
+                with open(child_err_path) as err:
                     raise RuntimeError(
                         f'Child process execution failed: return code {rc}.\n'
                         f'Error: {err.read()}'
@@ -407,7 +442,7 @@ class BenchmarkHarness(object):
         result_dir = args.result_dir
         client = StubbedHTTPClient()
         process_benchmarker = ProcessBenchmarker()
-        definitions = json.load(open(args.benchmark_definitions, 'r'))
+        definitions = json.load(open(args.benchmark_definitions))
         if os.path.exists(result_dir):
             shutil.rmtree(result_dir)
         os.makedirs(result_dir, 0o777)
@@ -420,12 +455,13 @@ class BenchmarkHarness(object):
                 }
                 if 'dimensions' in benchmark:
                     benchmark_result['dimensions'] = benchmark['dimensions']
-                for _ in range(args.num_iterations):
+                for iteration in range(args.num_iterations):
                     measurements = self._run_isolated_benchmark(
                         result_dir,
                         benchmark,
                         client,
                         process_benchmarker,
+                        iteration,
                         args,
                     )
                     benchmark_result['measurements'].append(measurements)
