@@ -14,22 +14,21 @@
 import socket
 
 import botocore.config
-from tests import get_botocore_default_config_mapping, mock, unittest
-
-from botocore import UNSIGNED, args
+from botocore import UNSIGNED, args, exceptions
 from botocore.args import PRIORITY_ORDERED_SUPPORTED_PROTOCOLS
-from botocore import exceptions
 from botocore.client import ClientEndpointBridge
 from botocore.config import Config
 from botocore.configprovider import ConfigValueStore
-from botocore.exceptions import UnsupportedServiceProtocolsError
 from botocore.credentials import Credentials
+from botocore.exceptions import UnsupportedServiceProtocolsError
 from botocore.hooks import HierarchicalEmitter
 from botocore.model import ServiceModel
 from botocore.parsers import PROTOCOL_PARSERS
 from botocore.serialize import SERIALIZERS
 from botocore.useragent import UserAgentString
 
+from tests import get_botocore_default_config_mapping, mock, unittest
+
 
 class TestCreateClientArgs(unittest.TestCase):
     def setUp(self):
@@ -88,7 +87,7 @@ class TestCreateClientArgs(unittest.TestCase):
             'endpoint_url': self.endpoint_url,
             'signing_name': self.service_name,
             'signing_region': self.region,
-            'metadata': {}
+            'metadata': {},
         }
         ret_val.update(**override_kwargs)
         self.bridge.resolve.return_value = ret_val
@@ -153,10 +152,11 @@ class TestCreateClientArgs(unittest.TestCase):
 
     def test_compute_s3_config_only_config_store(self):
         self.config_store.set_config_variable(
-            's3', {'use_accelerate_endpoint': True})
+            's3', {'use_accelerate_endpoint': True}
+        )
         self.assertEqual(
             self.args_create.compute_s3_config(None),
-            {'use_accelerate_endpoint': True}
+            {'use_accelerate_endpoint': True},
         )
 
     def test_client_s3_accelerate_from_client_config(self):
@@ -164,18 +164,19 @@ class TestCreateClientArgs(unittest.TestCase):
             self.args_create.compute_s3_config(
                 client_config=Config(s3={'use_accelerate_endpoint': True})
             ),
-            {'use_accelerate_endpoint': True}
+            {'use_accelerate_endpoint': True},
         )
 
     def test_client_s3_accelerate_client_config_overrides_config_store(self):
         self.config_store.set_config_variable(
-            's3', {'use_accelerate_endpoint': False})
+            's3', {'use_accelerate_endpoint': False}
+        )
         self.assertEqual(
             self.args_create.compute_s3_config(
                 client_config=Config(s3={'use_accelerate_endpoint': True})
             ),
             # client_config beats scoped_config
-            {'use_accelerate_endpoint': True}
+            {'use_accelerate_endpoint': True},
         )
 
     def test_max_pool_from_client_config_forwarded_to_endpoint_creator(self):
@@ -185,8 +186,10 @@ class TestCreateClientArgs(unittest.TestCase):
             self.assert_create_endpoint_call(m, max_pool_connections=20)
 
     def test_proxies_from_client_config_forwarded_to_endpoint_creator(self):
-        proxies = {'http': 'http://foo.bar:1234',
-                   'https': 'https://foo.bar:4321'}
+        proxies = {
+            'http': 'http://foo.bar:1234',
+            'https': 'https://foo.bar:4321',
+        }
         config = botocore.config.Config(proxies=proxies)
         with mock.patch('botocore.args.EndpointCreator') as m:
             self.call_get_client_args(client_config=config)
@@ -197,48 +200,60 @@ class TestCreateClientArgs(unittest.TestCase):
         self.service_model.metadata = {'protocol': 'rest-xml'}
         self.bridge.resolve.side_effect = [
             {
-                'region_name': None, 'signature_version': 's3v4',
-                'endpoint_url': 'http://other.com/', 'signing_name': 's3',
-                'signing_region': None, 'metadata': {}
+                'region_name': None,
+                'signature_version': 's3v4',
+                'endpoint_url': 'http://other.com/',
+                'signing_name': 's3',
+                'signing_region': None,
+                'metadata': {},
             },
             {
-                'region_name': 'us-west-2', 'signature_version': 's3v4',
+                'region_name': 'us-west-2',
+                'signature_version': 's3v4',
                 'enpoint_url': 'https://s3-us-west-2.amazonaws.com',
-                'signing_name': 's3', 'signing_region': 'us-west-2',
-                'metadata': {}
-            }
+                'signing_name': 's3',
+                'signing_region': 'us-west-2',
+                'metadata': {},
+            },
         ]
         client_args = self.call_get_client_args(
-            endpoint_url='http://other.com/')
-        self.assertEqual(
-            client_args['client_config'].region_name, 'us-west-2')
+            endpoint_url='http://other.com/'
+        )
+        self.assertEqual(client_args['client_config'].region_name, 'us-west-2')
 
     def test_region_does_not_resolve_if_not_s3_and_endpoint_url_provided(self):
         self.service_model.endpoint_prefix = 'ec2'
         self.service_model.metadata = {'protocol': 'query'}
-        self.bridge.resolve.side_effect = [{
-            'region_name': None, 'signature_version': 'v4',
-            'endpoint_url': 'http://other.com/', 'signing_name': 'ec2',
-            'signing_region': None, 'metadata': {}
-        }]
+        self.bridge.resolve.side_effect = [
+            {
+                'region_name': None,
+                'signature_version': 'v4',
+                'endpoint_url': 'http://other.com/',
+                'signing_name': 'ec2',
+                'signing_region': None,
+                'metadata': {},
+            }
+        ]
         client_args = self.call_get_client_args(
-            endpoint_url='http://other.com/')
+            endpoint_url='http://other.com/'
+        )
         self.assertEqual(client_args['client_config'].region_name, None)
 
     def test_provide_retry_config(self):
         config = botocore.config.Config(retries={'max_attempts': 10})
         client_args = self.call_get_client_args(client_config=config)
         self.assertEqual(
-            client_args['client_config'].retries['max_attempts'], 10)
+            client_args['client_config'].retries['max_attempts'], 10
+        )
 
     def test_tcp_keepalive_enabled(self):
         scoped_config = {'tcp_keepalive': 'true'}
         with mock.patch('botocore.args.EndpointCreator') as m:
             self.call_get_client_args(scoped_config=scoped_config)
             self.assert_create_endpoint_call(
-                m, socket_options=self.default_socket_options + [
-                    (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
-                ]
+                m,
+                socket_options=self.default_socket_options
+                + [(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)],
             )
 
     def test_tcp_keepalive_not_specified(self):
@@ -246,52 +261,46 @@ class TestCreateClientArgs(unittest.TestCase):
         with mock.patch('botocore.args.EndpointCreator') as m:
             self.call_get_client_args(scoped_config=scoped_config)
             self.assert_create_endpoint_call(
-                m, socket_options=self.default_socket_options)
+                m, socket_options=self.default_socket_options
+            )
 
     def test_tcp_keepalive_explicitly_disabled(self):
         scoped_config = {'tcp_keepalive': 'false'}
         with mock.patch('botocore.args.EndpointCreator') as m:
             self.call_get_client_args(scoped_config=scoped_config)
             self.assert_create_endpoint_call(
-                m, socket_options=self.default_socket_options)
+                m, socket_options=self.default_socket_options
+            )
 
     def test_tcp_keepalive_enabled_case_insensitive(self):
         scoped_config = {'tcp_keepalive': 'True'}
         with mock.patch('botocore.args.EndpointCreator') as m:
             self.call_get_client_args(scoped_config=scoped_config)
             self.assert_create_endpoint_call(
-                m, socket_options=self.default_socket_options + [
-                    (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
-                ]
+                m,
+                socket_options=self.default_socket_options
+                + [(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)],
             )
 
     def test_client_config_has_use_dualstack_endpoint_flag(self):
-        self._set_endpoint_bridge_resolve(
-            metadata={
-                'tags': ['dualstack']
-            }
-        )
+        self._set_endpoint_bridge_resolve(metadata={'tags': ['dualstack']})
         client_args = self.call_get_client_args(
             service_model=self._get_service_model('ec2'),
         )
         self.assertTrue(client_args['client_config'].use_dualstack_endpoint)
 
     def test_client_config_has_use_fips_endpoint_flag(self):
-        self._set_endpoint_bridge_resolve(
-            metadata={
-                'tags': ['fips']
-            }
-        )
+        self._set_endpoint_bridge_resolve(metadata={'tags': ['fips']})
         client_args = self.call_get_client_args(
             service_model=self._get_service_model('ec2'),
         )
         self.assertTrue(client_args['client_config'].use_fips_endpoint)
 
-    def test_client_config_has_both_use_fips_and_use_dualstack__endpoint_flags(self):
+    def test_client_config_has_both_use_fips_and_use_dualstack__endpoint_flags(
+        self,
+    ):
         self._set_endpoint_bridge_resolve(
-            metadata={
-                'tags': ['fips', 'dualstack']
-            }
+            metadata={'tags': ['fips', 'dualstack']}
         )
         client_args = self.call_get_client_args(
             service_model=self._get_service_model('ec2'),
@@ -300,30 +309,29 @@ class TestCreateClientArgs(unittest.TestCase):
         self.assertTrue(client_args['client_config'].use_dualstack_endpoint)
 
     def test_s3_override_use_dualstack_endpoint_flag(self):
-        self._set_endpoint_bridge_resolve(
-            metadata={
-                'tags': ['dualstack']
-            }
-        )
+        self._set_endpoint_bridge_resolve(metadata={'tags': ['dualstack']})
         client_args = self.call_get_client_args(
             service_model=self._get_service_model('s3'),
         )
-        self.assertTrue(client_args['client_config'].s3['use_dualstack_endpoint'])
+        self.assertTrue(
+            client_args['client_config'].s3['use_dualstack_endpoint']
+        )
 
     def test_sts_use_resolved_endpoint_for_regional_configuration(self):
         resolved_endpoint = 'https://resolved-endpoint'
         resolved_region = 'resolved-region'
         self._set_endpoint_bridge_resolve(
-            endpoint_url=resolved_endpoint,
-            signing_region=resolved_region
+            endpoint_url=resolved_endpoint, signing_region=resolved_region
         )
         client_args = self.call_get_client_args(
             service_model=self._get_service_model('sts'),
-            region_name='us-west-2', endpoint_url=None
+            region_name='us-west-2',
+            endpoint_url=None,
         )
         self.assertEqual(client_args['endpoint'].host, resolved_endpoint)
         self.assertEqual(
-            client_args['request_signer'].region_name, resolved_region)
+            client_args['request_signer'].region_name, resolved_region
+        )
 
     def test_can_merge_max_attempts(self):
         self.config_store.set_config_variable('max_attempts', 4)
@@ -332,27 +340,29 @@ class TestCreateClientArgs(unittest.TestCase):
 
     def test_uses_config_value_if_present_for_max_attempts(self):
         config = self.call_get_client_args(
-                client_config=Config(retries={'max_attempts': 2})
+            client_config=Config(retries={'max_attempts': 2})
         )['client_config']
         self.assertEqual(config.retries['max_attempts'], 2)
 
     def test_uses_client_config_over_config_store_max_attempts(self):
         self.config_store.set_config_variable('max_attempts', 4)
         config = self.call_get_client_args(
-                client_config=Config(retries={'max_attempts': 2})
+            client_config=Config(retries={'max_attempts': 2})
         )['client_config']
         self.assertEqual(config.retries['max_attempts'], 2)
 
     def test_max_attempts_matches_config_store_if_retries_is_none(self):
-        config = self.call_get_client_args(
-                client_config=Config(retries=None)
-        )['client_config']
+        config = self.call_get_client_args(client_config=Config(retries=None))[
+            'client_config'
+        ]
         self.assertEqual(
             config.retries,
             {
-                'max_attempts': self.config_store.get_config_variable('max_attempts'),
-                'mode': 'standard'
-            }
+                'max_attempts': self.config_store.get_config_variable(
+                    'max_attempts'
+                ),
+                'mode': 'standard',
+            },
         )
 
     def test_retry_mode_set_on_config_store(self):
@@ -362,14 +372,14 @@ class TestCreateClientArgs(unittest.TestCase):
 
     def test_retry_mode_set_on_client_config(self):
         config = self.call_get_client_args(
-                client_config=Config(retries={'mode': 'standard'})
+            client_config=Config(retries={'mode': 'standard'})
         )['client_config']
         self.assertEqual(config.retries['mode'], 'standard')
 
     def test_client_config_beats_config_store(self):
         self.config_store.set_config_variable('retry_mode', 'other-mode')
         config = self.call_get_client_args(
-                client_config=Config(retries={'mode': 'standard'})
+            client_config=Config(retries={'mode': 'standard'})
         )['client_config']
         self.assertEqual(config.retries['mode'], 'standard')
 
